@@ -5,7 +5,7 @@ Sys.setenv(TZ = 'UTC')
 tests.home <- getwd()
 setwd(tempdir())
 
-exampleWorkspace("exampleWorkspace")
+exampleWorkspace("exampleWorkspace", force = TRUE)
 setwd("exampleWorkspace")
 
 test_that("loadStudyData contains all the required elements", {
@@ -18,7 +18,7 @@ test_that("loadStudyData contains all the required elements", {
 test_that("loadStudyData stops if override contains unknown data.", {
 	expect_error(loadStudyData(tz = "Europe/Copenhagen", override = "test", start.time = NULL, stop.time = NULL,
 	  exclude.tags = NULL, disregard.parallels = TRUE),
-		"Some tag signals listed in 'override' (test) are not listed in the biometrics file.", fixed = TRUE)
+		"Some tags listed in 'override' (test) are not listed in the biometrics file.", fixed = TRUE)
 })
 
 test_that("loadStudyData recognizes both 'study.dot' and 'study.txt' files.", {
